scipy.special.errstate
======================

.. currentmodule:: scipy.special

.. autoclass:: errstate

   

   .. HACK
      .. autosummary::
         :toctree:
      
         errstate.__init__



   

